.. WTForms-Django documentation master file, created by
   sphinx-quickstart on Sun Nov 10 16:35:07 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

WTForms-Django documentation
============================

Contents:

.. toctree::
   :maxdepth: 2

   wtforms_django


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

